# RMLab Errors

Small python module for unified error handling.

## Installation

```
pip install rmlab-errors
```

## Requirements

* python 3.9+

## License

This package is offered under a [MIT License](LICENSE).